diff --git a/catalogue/RdbmsCatalogue.cpp b/catalogue/RdbmsCatalogue.cpp
index 9b6d324785b12e2d6abfb50012d326d9abac2989..b85a5edfa8ee2e08422c745c1501f181d17a29e8 100644
--- a/catalogue/RdbmsCatalogue.cpp
+++ b/catalogue/RdbmsCatalogue.cpp
@@ -3619,9 +3619,9 @@ std::list<common::dataStructures::ArchiveFile> RdbmsCatalogue::getArchiveFilesFo
 }
 
 //------------------------------------------------------------------------------
-// getArchiveFileSummary
+// getTapeFileSummary
 //------------------------------------------------------------------------------
-common::dataStructures::ArchiveFileSummary RdbmsCatalogue::getArchiveFileSummary(
+common::dataStructures::ArchiveFileSummary RdbmsCatalogue::getTapeFileSummary(
   const ArchiveFileSearchCriteria &searchCriteria) const {
   throw exception::Exception(std::string(__FUNCTION__) + " not implemented");
 }
diff --git a/xroot_plugins/XrdCtaFile.cpp b/xroot_plugins/XrdCtaFile.cpp
index 32d0ffe5d616be76b1ddeee51a36048f4c5fbc05..d37a5297c375b071b381d330730bff689bf732e9 100644
--- a/xroot_plugins/XrdCtaFile.cpp
+++ b/xroot_plugins/XrdCtaFile.cpp
@@ -1736,7 +1736,7 @@ void XrdCtaFile::xCom_archivefile() {
       }
     }
     else { //summary
-      cta::common::dataStructures::ArchiveFileSummary summary=m_catalogue->getArchiveFileSummary(searchCriteria);
+      cta::common::dataStructures::ArchiveFileSummary summary=m_catalogue->getTapeFileSummary(searchCriteria);
       std::vector<std::vector<std::string>> responseTable;
       std::vector<std::string> header = {"total number of files","total size"};
       std::vector<std::string> row = {std::to_string((unsigned long long)summary.totalFiles),std::to_string((unsigned long long)summary.totalBytes)};
diff --git a/catalogue/Catalogue.hpp b/catalogue/Catalogue.hpp
index bdf0d19ec722037dd0a7bdeee89c33cb56f2a6d5..a29e15b82b1ac0da1b2eaff7adc4295e3345a4f2 100644
--- a/catalogue/Catalogue.hpp
+++ b/catalogue/Catalogue.hpp
@@ -485,13 +485,13 @@ public:
     const uint64_t nbArchiveFilesToPrefetch = 1000) const = 0;
 
   /**
    * Returns a summary of the archive files that meet the specified search
    * criteria.
    *
    * @param searchCriteria The search criteria.
    * @return The summary.
    */
-  virtual common::dataStructures::ArchiveFileSummary getArchiveFileSummary(
+  virtual common::dataStructures::ArchiveFileSummary getTapeFileSummary(
     const ArchiveFileSearchCriteria &searchCriteria = ArchiveFileSearchCriteria()) const = 0;
 
   /**
@@ -485,13 +485,13 @@ public:
 
   /**
-   * Returns a summary of the archive files that meet the specified search
+   * Returns a summary of the tape files that meet the specified search
    * criteria.
    *
diff --git a/catalogue/RdbmsCatalogue.hpp b/catalogue/RdbmsCatalogue.hpp
index a18758791c545dad2341935bbed9f6101f0919fa..d4ca8ce6f049e0dc855ea8e0943c57be7dea9447 100644
--- a/catalogue/RdbmsCatalogue.hpp
+++ b/catalogue/RdbmsCatalogue.hpp
@@ -471,13 +471,13 @@ public:
     const uint64_t nbArchiveFilesToPrefetch) const override;
 
   /**
    * Returns a summary of the archive files that meet the specified search
    * criteria.
    *
    * @param searchCriteria The search criteria.
    * @return The summary.
    */
-  common::dataStructures::ArchiveFileSummary getArchiveFileSummary(
+  common::dataStructures::ArchiveFileSummary getTapeFileSummary(
     const ArchiveFileSearchCriteria &searchCriteria) const override;
 
   /**
@@ -471,13 +471,13 @@ public:
 
   /**
-   * Returns a summary of the archive files that meet the specified search
+   * Returns a summary of the tape files that meet the specified search
    * criteria.
    *